==> open-xchange-mobile-api-facade_1.4.0.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.0/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/connectors/BaseConnector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.connectors;

import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;

public abstract class BaseConnector<T extends AbstractResponseMto> extends AbstractConnector<T> {

    private final Class<T> responseBodyType;

    public BaseConnector(RequestConfiguration configuration, String module, Class<T> bodyType) {
        super(configuration, module);
        this.responseBodyType = bodyType;
    }

    public BaseConnector(RequestConfiguration configuration, SessionData sessionData, String module, Class<T> bodyType) {
        super(configuration, sessionData, module);
        this.responseBodyType = bodyType;
    }

    @Override
    protected JavaType getResponseBodyType(ObjectMapper mapper) {
        return mapper.getTypeFactory().constructType(responseBodyType);
    }

    @Override
    protected boolean isError(T responseBody) {
        return responseBody.isError();
    }

    @Override
    protected ApiFacadeException handleErrors(T responseBody) {
        return ApiFacadeException.fromResponseBody(responseBody);
    }

}

==> open-xchange-mobile-api-facade_1.10.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.10.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/connectors/BaseConnector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.connectors;

import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;

public abstract class BaseConnector<T extends AbstractResponseMto> extends AbstractConnector<T> {

    private final Class<T> responseBodyType;

    public BaseConnector(RequestConfiguration configuration, String module, Class<T> bodyType) {
        super(configuration, module);
        this.responseBodyType = bodyType;
    }

    public BaseConnector(RequestConfiguration configuration, SessionData sessionData, String module, Class<T> bodyType) {
        super(configuration, sessionData, module);
        this.responseBodyType = bodyType;
    }

    @Override
    protected JavaType getResponseBodyType(ObjectMapper mapper) {
        return mapper.getTypeFactory().constructType(responseBodyType);
    }

    @Override
    protected boolean isError(T responseBody) {
        return responseBody != null && responseBody.isError();
    }

    @Override
    protected ApiFacadeException handleErrors(T responseBody) {
        return ApiFacadeException.fromResponseBody(responseBody);
    }

}
